pub struct ChickenSoundVariant {
pub key: Identifier,
pub baby_sounds: ChickenAge,
pub adult_sounds: ChickenAge,
}Expand description
Represents a set of sounds for a chicken variant from a data pack JSON file.
Fields
key: Identifierbaby_sounds: ChickenAgeadult_sounds: ChickenAgeTrait Implementations
Sourceimpl Debug for ChickenSoundVariant
impl Debug for ChickenSoundVariant
impl Eq for ChickenSoundVariant
Sourceimpl PartialEq for ChickenSoundVariant
impl PartialEq for ChickenSoundVariant
Sourceimpl RegistryEntry for ChickenSoundVariant
impl RegistryEntry for ChickenSoundVariant
Sourceimpl RegistryReferenceEntry for ChickenSoundVariant
impl RegistryReferenceEntry for ChickenSoundVariant
Sourceconst REGISTRY_NAME: &'static str = "chicken sound variant"
const REGISTRY_NAME: &'static str = "chicken sound variant"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourceimpl ToNbtTag for &ChickenSoundVariant
impl ToNbtTag for &ChickenSoundVariant
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>